@@ -49,13 +49,13 @@ bow_out (void)
 {
   dirtempunlink ();
   tempunlink ();
-  _Exit (EXIT_FAILURE);
+  exit_failurefully ();
 }
 
 static exiting void
 scram (void)
 {
-  _Exit (EXIT_FAILURE);
+  exit_failurefully ();
 }
 
 /* Removed by eggert 1995-06-01.  */
@@ -307,7 +307,7 @@ dump_hash_table (struct repo *r)
 static exiting void
 exiterr (void)
 {
-  _Exit (1);
+  exit_failurefully ();
 }
 
 static const struct program program = { .name = "y-GROK", .exiterr = exiterr };
